@@ -1,16 +1,10 @@
 #!/usr/bin/env python3
-# Time-stamp: "2021-09-25 15:17:32 (ylab)"
-
-from . import dsp
-from . import general
-from . import ml
-from . import plt
-from . import stats
-from . import resource
+# Time-stamp: "2021-10-11 19:49:24 (ylab)"
 
+from . import dsp, general, ml, plt, resource, stats
 
 __copyright__ = "Copyright (C) 2021 Yusuke Watanabe"
-__version__ = "0.0.22"
+__version__ = "0.0.28"
 __license__ = "GPL3.0"
 __author__ = "ywatanabe1989"
 __author_email__ = "ywata1989@gmail.com"
