@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-from _bonferroni_correction import bonferroni_correction
+from ._bonferroni_correction import bonferroni_correction
 from ._brunner_munzel_test import brunner_munzel_test
 from ._multicompair import multicompair
 from ._nocorrelation_test import nocorrelation_test
